@@ -1,6 +1,6 @@
 from datetime import datetime, date, time
-from sqlalchemy import create_engine
-from sqlalchemy.orm import scoped_session, sessionmaker, aliased
+from sqlalchemy import create_engine, event
+from sqlalchemy.orm import scoped_session, sessionmaker, aliased, mapper
 from sqlalchemy.dialects import mysql
 from sqlalchemy import exists, desc, text, and_
 from sqlalchemy.inspection import inspect
@@ -23,6 +23,15 @@ class Repository:
         self.engine = create_engine(f'mysql+pymysql://{username}:{password}@{host}:{port}/{database}', echo=False) # , isolation_level='READ UNCOMMITTED')
         Session = sessionmaker(bind=self.engine)
         self.session = scoped_session(Session)
+
+        event.listen(Session, 'init', auto_add)
+        event.listen(Session, 'after_commit', auto_detach)
+
+        def auto_add(session):
+            Session.add(session)
+
+        def auto_detach(session):
+            Session.detach(session)        
   
     def save(self, entity: any) -> None:
         '''
